﻿using System;
using System.Collections.Generic;
using UnityEngine;

namespace Mod
{
    static class PeopleManager
    {
        private static bool initilized = false;

        public static Dictionary<string, Texture2D> textures = new Dictionary<string, Texture2D>();
        public static Dictionary<string, Sprite> thumbnails = new Dictionary<string, Sprite>();

        public static void LoadAssets()
        {
            if (initilized)
            {
                return;
            }

            foreach (Person p in People.people)
            {
                
                var skin = ModAPI.LoadTexture(String.Format("./gfx/{0}/{0}.png", p.Name));
                var flesh = ModAPI.LoadTexture(String.Format("./gfx/{0}/{0}_flesh.png", p.Name));
                var bone = ModAPI.LoadTexture(String.Format("./gfx/{0}/{0}_bone.png", p.Name));
                var thumb = ModAPI.LoadSprite(String.Format("./gfx/{0}/{0}_thumb.png", p.Name));

                if (skin != null)
                    textures.Add(p.Name, skin);

                if (flesh != null)
                    textures.Add(p.Name + "_flesh", flesh);

                if (bone != null)
                    textures.Add(p.Name + "_bone", bone);

                if (thumb != null)
                    thumbnails.Add(p.Name, thumb);
            }

            initilized = true;
        }

        public static void RegisterPeople()
        {
            foreach (Person p in People.people)
            {
                ModAPI.Register(new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"),

                    NameOverride = p.DisplayName,

                    DescriptionOverride = p.Requestee == null ?
                                          p.Description :
                                          p.Description + String.Format("\n\nIdea by: {0}", p.Requestee),

                    ThumbnailOverride = thumbnails.ContainsKey(p.Name) ?
                                        thumbnails[p.Name] :
                                        null,

                    CategoryOverride = ModAPI.FindCategory("Entities"),

                    AfterSpawn = (Instance) =>
                    {
                        PersonBehaviour b = Instance.GetComponent<PersonBehaviour>();

                        Texture2D skin = null;
                        Texture2D flesh = null;
                        Texture2D bone = null;

                        if (textures.ContainsKey(p.Name))
                            skin = textures[p.Name];

                        if (textures.ContainsKey(p.Name + "_flesh"))
                            flesh = textures[p.Name + "_flesh"];

                        if (textures.ContainsKey(p.Name + "_bone"))
                            bone = textures[p.Name + "_bone"];

                        b.SetBodyTextures(skin, flesh, bone);

                        b.SetBruiseColor(50, 0, 0);
                        b.SetSecondBruiseColor(75, 0, 0);
                        b.SetThirdBruiseColor(100, 0, 0);
                    }
                });
            }
        }
    }
}
